==> apache-camel-2.24.2-src.zip: apache-camel-2.24.2/components/camel-mllp/src/test/java/org/apache/camel/test/junit/rule/mllp/MllpJUnitResourceTimeoutException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.test.junit.rule.mllp;

/**
 * Thrown when one of the MLLP JUnit Rules encounters an unexpected timeout
 */
public class MllpJUnitResourceTimeoutException extends MllpJUnitResourceException {
    public MllpJUnitResourceTimeoutException(String message) {
        super(message);
    }

    public MllpJUnitResourceTimeoutException(String message, Throwable cause) {
        super(message, cause);
    }

    public MllpJUnitResourceTimeoutException(Throwable cause) {
        super(cause);
    }

    public MllpJUnitResourceTimeoutException(String message, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
        super(message, cause, enableSuppression, writableStackTrace);
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-mllp/src/test/java/org/apache/camel/test/junit/rule/mllp/MllpJUnitResourceTimeoutException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.test.junit.rule.mllp;

/**
 * Thrown when one of the MLLP JUnit Rules encounters an unexpected timeout
 */
public class MllpJUnitResourceTimeoutException extends MllpJUnitResourceException {
    public MllpJUnitResourceTimeoutException(String message) {
        super(message);
    }

    public MllpJUnitResourceTimeoutException(String message, Throwable cause) {
        super(message, cause);
    }

    public MllpJUnitResourceTimeoutException(Throwable cause) {
        super(cause);
    }

    public MllpJUnitResourceTimeoutException(String message, Throwable cause, boolean enableSuppression,
                                             boolean writableStackTrace) {
        super(message, cause, enableSuppression, writableStackTrace);
    }
}
